@@ -1,23 +1,12 @@
-/*
- *  Copyright (C) 2015 Boudhayan Gupta <bgupta@kde.org>
- *
- *  This program is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU Lesser General Public License as published by
- *  the Free Software Foundation; either version 2 of the License, or
- *  (at your option) any later version.
- *
- *  This program is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU General Public License for more details.
- *
- *  You should have received a copy of the GNU Lesser General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 51 Franklin Street, Fifth Floor,
- *  Boston, MA 02110-1301, USA.
+/* This file is part of Spectacle, the KDE screenshot utility
+ * SPDX-FileCopyrightText: 2015 Boudhayan Gupta <bgupta@kde.org>
+ * SPDX-License-Identifier: LGPL-2.0-or-later
  */
 
 #include "KSImageWidget.h"
+#include <KLocalizedString>
+#include <QGuiApplication>
+#include <QStyleHints>
 
 KSImageWidget::KSImageWidget(QWidget *parent):
     QLabel(parent),
@@ -25,7 +14,7 @@ KSImageWidget::KSImageWidget(QWidget *parent):
 {
     mDSEffect = new QGraphicsDropShadowEffect(this);
 
-    mDSEffect->setBlurRadius(5);
+    mDSEffect->setBlurRadius(SpectacleImage::SHADOW_RADIUS);
     mDSEffect->setOffset(0);
     mDSEffect->setColor(QColor(Qt::black));
 
@@ -85,7 +74,7 @@ void KSImageWidget::mouseMoveEvent(QMouseEvent *event)
 
 void KSImageWidget::resizeEvent(QResizeEvent *event)
 {
-    Q_UNUSED(event);
+    Q_UNUSED(event)
     setScaledPixmap();
 }
 
