@@ -22,6 +22,7 @@ ShortcutActions::ShortcutActions() : mActions{nullptr, QString()}
     mActions.setComponentName(componentName());
     //qdbus org.kde.kglobalaccel /component/org_kde_spectacle_desktop org.kde.kglobalaccel.Component.shortcutNames
     // ActiveWindowScreenShot
+    // WindowUnderCursorScreenShot
     // CurrentMonitorScreenShot
     // RectangularRegionScreenShot
     // FullScreenScreenShot
@@ -51,6 +52,11 @@ ShortcutActions::ShortcutActions() : mActions{nullptr, QString()}
         action->setObjectName(QStringLiteral("RectangularRegionScreenShot"));
         mActions.addAction(action->objectName(), action);
     }
+    {
+        QAction *action = new QAction(i18n("Capture Window Under Cursor"));
+        action->setObjectName(QStringLiteral("WindowUnderCursorScreenShot"));
+        mActions.addAction(action->objectName(), action);
+    }
 }
 
 KActionCollection* ShortcutActions::shortcutActions()
@@ -87,3 +93,8 @@ QAction* ShortcutActions::regionAction() const
 {
     return mActions.action(4);
 }
+
+QAction* ShortcutActions::windowUnderCursorAction() const
+{
+    return mActions.action(5);
+}
